projectal.entities.rebate API documentation

# projectal.entities.rebate

View Source

    from projectal.entity import Entity

    class Rebate(Entity):
        """
        Implementation of the [Rebate](https://projectal.com/docs/latest/#tag/Rebate) API.
        """
        _path = 'rebate'
        _name = 'REBATE'

class Rebate(projectal.entity.Entity):
View Source

    class Rebate(Entity):
        """
        Implementation of the [Rebate](https://projectal.com/docs/latest/#tag/Rebate) API.
        """
        _path = 'rebate'
        _name = 'REBATE'

Implementation of the Rebate API.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  create
  save
  clone
  history
  list
  match
  match_startswith
  match_endswith
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy